==> apache-ignite-2.7.0-bin.zip: apache-ignite-2.7.0-bin/platforms/cpp/docs/search/all_11.js <==
var searchData=
[
  ['scanquery',['ScanQuery',['../classignite_1_1cache_1_1query_1_1ScanQuery.html',1,'ignite::cache::query']]],
  ['scanquery',['ScanQuery',['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a5a55d6bee94c6493eaa28a80998bdeda',1,'ignite::cache::query::ScanQuery::ScanQuery()'],['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a9ecccb5eb3666d47e9e303634409fc9d',1,'ignite::cache::query::ScanQuery::ScanQuery(int32_t part)']]],
  ['serializable',['SERIALIZABLE',['../structignite_1_1transactions_1_1TransactionIsolation.html#a3ac24463ce4e1f63186a974c33c6b3e3a8dadab2cb79ed7d2d0ed91f692fa3b27',1,'ignite::transactions::TransactionIsolation']]],
  ['setactive',['SetActive',['../classignite_1_1Ignite.html#a481375583b96f54119ef604338cfc5b8',1,'ignite::Ignite']]],
  ['setbuffersize',['SetBufferSize',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a755b5cf8a7ea00e0b19c37b6b589efc3',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['setdistributedjoins',['SetDistributedJoins',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aeb4896f55a3231852a8840eab1758f3c',1,'ignite::cache::query::SqlQuery::SetDistributedJoins()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a83bdd97f4a9f3f13f23103ad018b84de',1,'ignite::cache::query::SqlFieldsQuery::SetDistributedJoins()']]],
  ['setendpoints',['SetEndPoints',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a57dbf8199cd60518c80dd95b0dead9e8',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setenforcejoinorder',['SetEnforceJoinOrder',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ad489c8b5da47b8c6a0e8fd1dd758daa2',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['seterror',['SetError',['../classignite_1_1IgniteError.html#a960372e47aaa23149a70af53582fa04e',1,'ignite::IgniteError']]],
  ['setlazy',['SetLazy',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a82f2a74cd3dc9c55c3ed3f4ec25c5a33',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['setlistener',['SetListener',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a88f43a94603ad2b6a0bb39cff88eaded',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['setlocal',['SetLocal',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#aef8dbf5f7809d8104963fb50aa7db40c',1,'ignite::cache::query::continuous::ContinuousQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a353a5b9cedbe16411aa0341328126856',1,'ignite::cache::query::ScanQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a907b6e4a5c4ea7ca6f80a3b687091f22',1,'ignite::cache::query::SqlQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ac20c97dfefd05e690242a918022a5bbf',1,'ignite::cache::query::SqlFieldsQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a2d4e4aac39e4c1ea3ad1499b135b6012',1,'ignite::cache::query::TextQuery::SetLocal()']]],
  ['setpagesize',['SetPageSize',['../classignite_1_1cache_1_1query_1_1ScanQuery.html#ad459033dcf311b1b25e46fb1dbb2b55e',1,'ignite::cache::query::ScanQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aadf500528211e00a43cf7b87c0d0051f',1,'ignite::cache::query::SqlQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#acd61be0cefd04d766a4418686eb49f4a',1,'ignite::cache::query::SqlFieldsQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a1c385b1e320ec6a6387dea04d10f0f59',1,'ignite::cache::query::TextQuery::SetPageSize()']]],
  ['setpartition',['SetPartition',['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a55fb7a45eb8520fd949c0f749dfa53ba',1,'ignite::cache::query::ScanQuery']]],
  ['setpassword',['SetPassword',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#abcb462bcae7e29f81d6ee9ff71e1321d',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setrollbackonly',['SetRollbackOnly',['../classignite_1_1transactions_1_1Transaction.html#a346e9f015ab64052605014bedfe8dcb9',1,'ignite::transactions::Transaction::SetRollbackOnly()'],['../classignite_1_1transactions_1_1Transaction.html#a5e985369f83c4ac4c567ef6262cbff2d',1,'ignite::transactions::Transaction::SetRollbackOnly(IgniteError &amp;err)']]],
  ['setschema',['SetSchema',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#af2bca796c1ed5fa8357c49946349687e',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['setsql',['SetSql',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aa4e9e9a79ea5ddbf8c8c0aada68f3b6d',1,'ignite::cache::query::SqlQuery::SetSql()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a647110f3e40f812667f43db86d04dd81',1,'ignite::cache::query::SqlFieldsQuery::SetSql()']]],
  ['setsslcafile',['SetSslCaFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#aaac36e365275decb20dc8767c3587cb5',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslcertfile',['SetSslCertFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a41b693eb6303d4617bc338b6afa77318',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslkeyfile',['SetSslKeyFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#aa21d7538c5aebb18be6593eb629dc464',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslmode',['SetSslMode',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a254e0351a4430280c81ee7cb1ad324e3',1,'ignite::thin::IgniteClientConfiguration']]],
  ['settext',['SetText',['../classignite_1_1cache_1_1query_1_1TextQuery.html#a89aae4e4a05f41976c103a461d953e0e',1,'ignite::cache::query::TextQuery']]],
  ['settimeinterval',['SetTimeInterval',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a6abb33c89aab001f5035ea913c200fdb',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['settype',['SetType',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a5609ce4f4005383181bf24c0768a7846',1,'ignite::cache::query::SqlQuery::SetType()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a5fb83c95ebefe5b14fdafb839d460538',1,'ignite::cache::query::TextQuery::SetType()']]],
  ['setuser',['SetUser',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a2699b733dec083ad203827237da76cbe',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setvalue',['SetValue',['../classignite_1_1cache_1_1MutableCacheEntry.html#a66b8f2c851cfd737f55042a8fb2791c4',1,'ignite::cache::MutableCacheEntry']]],
  ['size',['Size',['../classignite_1_1cache_1_1Cache.html#a03574797da901a76180aad88476ef8ce',1,'ignite::cache::Cache::Size()'],['../classignite_1_1cache_1_1Cache.html#aeceeba2bacfa25940980144204457857',1,'ignite::cache::Cache::Size(IgniteError &amp;err)'],['../classignite_1_1cache_1_1Cache.html#ae2a4bc2ff23bb72bd6338d3003c8d9f7',1,'ignite::cache::Cache::Size(int32_t peekModes)'],['../classignite_1_1cache_1_1Cache.html#a601e93893fa8836baad3d10d3174fe13',1,'ignite::cache::Cache::Size(int32_t peekModes, IgniteError &amp;err)']]],
  ['springcfgpath',['springCfgPath',['../structignite_1_1IgniteConfiguration.html#afd23553f3a6f646741552e3d5e9d8283',1,'ignite::IgniteConfiguration']]],
  ['sqlfieldsquery',['SqlFieldsQuery',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#aba1e988e00b3cacc3a0190f65801de24',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const std::string &amp;sql)'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ae236e1b1b11d99715c43ed6fcd818b0f',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const std::string &amp;sql, bool loc)'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ab1bdc1571644602a8455350db23ef492',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const SqlFieldsQuery &amp;other)']]],
  ['sqlfieldsquery',['SqlFieldsQuery',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html',1,'ignite::cache::query']]],
  ['sqlquery',['SqlQuery',['../classignite_1_1cache_1_1query_1_1SqlQuery.html',1,'ignite::cache::query']]],
  ['sqlquery',['SqlQuery',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aaa012e38597bf19751ebfb44642d1eec',1,'ignite::cache::query::SqlQuery::SqlQuery(const std::string &amp;type, const std::string &amp;sql)'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#afd18d1a83311dc68fe37629846849bc1',1,'ignite::cache::query::SqlQuery::SqlQuery(const SqlQuery &amp;other)']]],
  ['ssl_5fmode_2eh',['ssl_mode.h',['../ssl__mode_8h.html',1,'']]],
  ['sslmode',['SslMode',['../structignite_1_1thin_1_1SslMode.html',1,'ignite::thin']]],
  ['start',['Start',['../classignite_1_1Ignition.html#a93de29f22dcc6473a2a30a5998873c9d',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg)'],['../classignite_1_1Ignition.html#ac829502ac276a8bdff91b55daeb323b5',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, IgniteError &amp;err)'],['../classignite_1_1Ignition.html#ae8ca57c68aba19ce0024b084171d2819',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, const char *name)'],['../classignite_1_1Ignition.html#a5e950e39358bdf9374db13aa58484244',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, const char *name, IgniteError &amp;err)'],['../classignite_1_1thin_1_1IgniteClient.html#adf731f065a32d512a0caf23901bed571',1,'ignite::thin::IgniteClient::Start()']]],
  ['started',['started',['../namespaceignite.html#a340fa66fbb410168be7d201fd48d9515',1,'ignite']]],
  ['stop',['Stop',['../classignite_1_1Ignition.html#a09b5c98ddeb2f81a386930c59b504cbb',1,'ignite::Ignition::Stop(bool cancel)'],['../classignite_1_1Ignition.html#a36c23a742c9e71b947f497fb23044cb2',1,'ignite::Ignition::Stop(bool cancel, IgniteError &amp;err)'],['../classignite_1_1Ignition.html#a392755938ed670e94271460610a793a8',1,'ignite::Ignition::Stop(const char *name, bool cancel)'],['../classignite_1_1Ignition.html#aa6d6b876c073baa3d65ffe632778d56f',1,'ignite::Ignition::Stop(const char *name, bool cancel, IgniteError &amp;err)']]],
  ['stopall',['StopAll',['../classignite_1_1Ignition.html#af80a005a35ce388063b7533523728804',1,'ignite::Ignition::StopAll(bool cancel)'],['../classignite_1_1Ignition.html#a80cdec02fcd47dd2cbcaccb3c0b4a0a2',1,'ignite::Ignition::StopAll(bool cancel, IgniteError &amp;err)']]],
  ['swap',['SWAP',['../structignite_1_1cache_1_1CachePeekMode.html#acd2d0e89b2c2c9d391060a89585bc2b2a36ad9d80fd6d24a1353213cf770ae9eb',1,'ignite::cache::CachePeekMode::SWAP()'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a5591e0ffb6e596985bc9fc575d838c89',1,'ignite::cache::query::SqlQuery::Swap()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a856243c6eeba629483573fe983fcbc73',1,'ignite::cache::query::SqlFieldsQuery::Swap()']]]
];

==> apache-ignite-2.7.5-bin.zip: apache-ignite-2.7.5-bin/platforms/cpp/docs/search/all_11.js <==
var searchData=
[
  ['scanquery',['ScanQuery',['../classignite_1_1cache_1_1query_1_1ScanQuery.html',1,'ignite::cache::query::ScanQuery'],['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a5a55d6bee94c6493eaa28a80998bdeda',1,'ignite::cache::query::ScanQuery::ScanQuery()'],['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a9ecccb5eb3666d47e9e303634409fc9d',1,'ignite::cache::query::ScanQuery::ScanQuery(int32_t part)']]],
  ['serializable',['SERIALIZABLE',['../structignite_1_1transactions_1_1TransactionIsolation.html#a3ac24463ce4e1f63186a974c33c6b3e3a8dadab2cb79ed7d2d0ed91f692fa3b27',1,'ignite::transactions::TransactionIsolation']]],
  ['setactive',['SetActive',['../classignite_1_1Ignite.html#a481375583b96f54119ef604338cfc5b8',1,'ignite::Ignite']]],
  ['setbuffersize',['SetBufferSize',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a755b5cf8a7ea00e0b19c37b6b589efc3',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['setdistributedjoins',['SetDistributedJoins',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aeb4896f55a3231852a8840eab1758f3c',1,'ignite::cache::query::SqlQuery::SetDistributedJoins()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a83bdd97f4a9f3f13f23103ad018b84de',1,'ignite::cache::query::SqlFieldsQuery::SetDistributedJoins()']]],
  ['setendpoints',['SetEndPoints',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a57dbf8199cd60518c80dd95b0dead9e8',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setenforcejoinorder',['SetEnforceJoinOrder',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ad489c8b5da47b8c6a0e8fd1dd758daa2',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['seterror',['SetError',['../classignite_1_1IgniteError.html#a960372e47aaa23149a70af53582fa04e',1,'ignite::IgniteError']]],
  ['setlazy',['SetLazy',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a82f2a74cd3dc9c55c3ed3f4ec25c5a33',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['setlistener',['SetListener',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a88f43a94603ad2b6a0bb39cff88eaded',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['setlocal',['SetLocal',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#aef8dbf5f7809d8104963fb50aa7db40c',1,'ignite::cache::query::continuous::ContinuousQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a353a5b9cedbe16411aa0341328126856',1,'ignite::cache::query::ScanQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a907b6e4a5c4ea7ca6f80a3b687091f22',1,'ignite::cache::query::SqlQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ac20c97dfefd05e690242a918022a5bbf',1,'ignite::cache::query::SqlFieldsQuery::SetLocal()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a2d4e4aac39e4c1ea3ad1499b135b6012',1,'ignite::cache::query::TextQuery::SetLocal()']]],
  ['setpagesize',['SetPageSize',['../classignite_1_1cache_1_1query_1_1ScanQuery.html#ad459033dcf311b1b25e46fb1dbb2b55e',1,'ignite::cache::query::ScanQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aadf500528211e00a43cf7b87c0d0051f',1,'ignite::cache::query::SqlQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#acd61be0cefd04d766a4418686eb49f4a',1,'ignite::cache::query::SqlFieldsQuery::SetPageSize()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a1c385b1e320ec6a6387dea04d10f0f59',1,'ignite::cache::query::TextQuery::SetPageSize()']]],
  ['setpartition',['SetPartition',['../classignite_1_1cache_1_1query_1_1ScanQuery.html#a55fb7a45eb8520fd949c0f749dfa53ba',1,'ignite::cache::query::ScanQuery']]],
  ['setpassword',['SetPassword',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#abcb462bcae7e29f81d6ee9ff71e1321d',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setrollbackonly',['SetRollbackOnly',['../classignite_1_1transactions_1_1Transaction.html#a346e9f015ab64052605014bedfe8dcb9',1,'ignite::transactions::Transaction::SetRollbackOnly()'],['../classignite_1_1transactions_1_1Transaction.html#a5e985369f83c4ac4c567ef6262cbff2d',1,'ignite::transactions::Transaction::SetRollbackOnly(IgniteError &amp;err)']]],
  ['setschema',['SetSchema',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#af2bca796c1ed5fa8357c49946349687e',1,'ignite::cache::query::SqlFieldsQuery']]],
  ['setsql',['SetSql',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aa4e9e9a79ea5ddbf8c8c0aada68f3b6d',1,'ignite::cache::query::SqlQuery::SetSql()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a647110f3e40f812667f43db86d04dd81',1,'ignite::cache::query::SqlFieldsQuery::SetSql()']]],
  ['setsslcafile',['SetSslCaFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#aaac36e365275decb20dc8767c3587cb5',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslcertfile',['SetSslCertFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a41b693eb6303d4617bc338b6afa77318',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslkeyfile',['SetSslKeyFile',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#aa21d7538c5aebb18be6593eb629dc464',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setsslmode',['SetSslMode',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a254e0351a4430280c81ee7cb1ad324e3',1,'ignite::thin::IgniteClientConfiguration']]],
  ['settext',['SetText',['../classignite_1_1cache_1_1query_1_1TextQuery.html#a89aae4e4a05f41976c103a461d953e0e',1,'ignite::cache::query::TextQuery']]],
  ['settimeinterval',['SetTimeInterval',['../classignite_1_1cache_1_1query_1_1continuous_1_1ContinuousQuery.html#a6abb33c89aab001f5035ea913c200fdb',1,'ignite::cache::query::continuous::ContinuousQuery']]],
  ['settype',['SetType',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a5609ce4f4005383181bf24c0768a7846',1,'ignite::cache::query::SqlQuery::SetType()'],['../classignite_1_1cache_1_1query_1_1TextQuery.html#a5fb83c95ebefe5b14fdafb839d460538',1,'ignite::cache::query::TextQuery::SetType()']]],
  ['setuser',['SetUser',['../classignite_1_1thin_1_1IgniteClientConfiguration.html#a2699b733dec083ad203827237da76cbe',1,'ignite::thin::IgniteClientConfiguration']]],
  ['setvalue',['SetValue',['../classignite_1_1cache_1_1MutableCacheEntry.html#a66b8f2c851cfd737f55042a8fb2791c4',1,'ignite::cache::MutableCacheEntry']]],
  ['size',['Size',['../classignite_1_1cache_1_1Cache.html#a03574797da901a76180aad88476ef8ce',1,'ignite::cache::Cache::Size()'],['../classignite_1_1cache_1_1Cache.html#aeceeba2bacfa25940980144204457857',1,'ignite::cache::Cache::Size(IgniteError &amp;err)'],['../classignite_1_1cache_1_1Cache.html#ae2a4bc2ff23bb72bd6338d3003c8d9f7',1,'ignite::cache::Cache::Size(int32_t peekModes)'],['../classignite_1_1cache_1_1Cache.html#a601e93893fa8836baad3d10d3174fe13',1,'ignite::cache::Cache::Size(int32_t peekModes, IgniteError &amp;err)']]],
  ['springcfgpath',['springCfgPath',['../structignite_1_1IgniteConfiguration.html#afd23553f3a6f646741552e3d5e9d8283',1,'ignite::IgniteConfiguration']]],
  ['sqlfieldsquery',['SqlFieldsQuery',['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html',1,'ignite::cache::query::SqlFieldsQuery'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#aba1e988e00b3cacc3a0190f65801de24',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const std::string &amp;sql)'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ae236e1b1b11d99715c43ed6fcd818b0f',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const std::string &amp;sql, bool loc)'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#ab1bdc1571644602a8455350db23ef492',1,'ignite::cache::query::SqlFieldsQuery::SqlFieldsQuery(const SqlFieldsQuery &amp;other)']]],
  ['sqlquery',['SqlQuery',['../classignite_1_1cache_1_1query_1_1SqlQuery.html',1,'ignite::cache::query::SqlQuery'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#aaa012e38597bf19751ebfb44642d1eec',1,'ignite::cache::query::SqlQuery::SqlQuery(const std::string &amp;type, const std::string &amp;sql)'],['../classignite_1_1cache_1_1query_1_1SqlQuery.html#afd18d1a83311dc68fe37629846849bc1',1,'ignite::cache::query::SqlQuery::SqlQuery(const SqlQuery &amp;other)']]],
  ['ssl_5fmode_2eh',['ssl_mode.h',['../ssl__mode_8h.html',1,'']]],
  ['sslmode',['SslMode',['../structignite_1_1thin_1_1SslMode.html',1,'ignite::thin']]],
  ['start',['Start',['../classignite_1_1Ignition.html#a93de29f22dcc6473a2a30a5998873c9d',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg)'],['../classignite_1_1Ignition.html#ac829502ac276a8bdff91b55daeb323b5',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, IgniteError &amp;err)'],['../classignite_1_1Ignition.html#ae8ca57c68aba19ce0024b084171d2819',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, const char *name)'],['../classignite_1_1Ignition.html#a5e950e39358bdf9374db13aa58484244',1,'ignite::Ignition::Start(const IgniteConfiguration &amp;cfg, const char *name, IgniteError &amp;err)'],['../classignite_1_1thin_1_1IgniteClient.html#adf731f065a32d512a0caf23901bed571',1,'ignite::thin::IgniteClient::Start()']]],
  ['started',['started',['../namespaceignite.html#a340fa66fbb410168be7d201fd48d9515',1,'ignite']]],
  ['stop',['Stop',['../classignite_1_1Ignition.html#a09b5c98ddeb2f81a386930c59b504cbb',1,'ignite::Ignition::Stop(bool cancel)'],['../classignite_1_1Ignition.html#a36c23a742c9e71b947f497fb23044cb2',1,'ignite::Ignition::Stop(bool cancel, IgniteError &amp;err)'],['../classignite_1_1Ignition.html#a392755938ed670e94271460610a793a8',1,'ignite::Ignition::Stop(const char *name, bool cancel)'],['../classignite_1_1Ignition.html#aa6d6b876c073baa3d65ffe632778d56f',1,'ignite::Ignition::Stop(const char *name, bool cancel, IgniteError &amp;err)']]],
  ['stopall',['StopAll',['../classignite_1_1Ignition.html#af80a005a35ce388063b7533523728804',1,'ignite::Ignition::StopAll(bool cancel)'],['../classignite_1_1Ignition.html#a80cdec02fcd47dd2cbcaccb3c0b4a0a2',1,'ignite::Ignition::StopAll(bool cancel, IgniteError &amp;err)']]],
  ['swap',['Swap',['../classignite_1_1cache_1_1query_1_1SqlQuery.html#a5591e0ffb6e596985bc9fc575d838c89',1,'ignite::cache::query::SqlQuery::Swap()'],['../classignite_1_1cache_1_1query_1_1SqlFieldsQuery.html#a856243c6eeba629483573fe983fcbc73',1,'ignite::cache::query::SqlFieldsQuery::Swap()'],['../structignite_1_1cache_1_1CachePeekMode.html#acd2d0e89b2c2c9d391060a89585bc2b2a36ad9d80fd6d24a1353213cf770ae9eb',1,'ignite::cache::CachePeekMode::SWAP()']]]
];
